#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 tagged
version:              0.8.6.1
visibility:           public
id:                   tagged-0.8.6.1-F25vmSN4H5fEaMJYsLgYMV
key:                  tagged-0.8.6.1-F25vmSN4H5fEaMJYsLgYMV
license:              BSD-3-Clause
copyright:            2009-2015 Edward A. Kmett
maintainer:           Edward A. Kmett <ekmett@gmail.com>
author:               Edward A. Kmett
stability:            experimental
homepage:             http://github.com/ekmett/tagged
synopsis:
    Haskell 98 phantom types to avoid unsafely passing dummy arguments

description:
    Haskell 98 phantom types to avoid unsafely passing dummy arguments.

category:             Data, Phantom Types
abi:                  47a2ef92381af8564674ada9c742253f
exposed:              True
exposed-modules:      Data.Proxy.TH Data.Tagged
import-dirs:          /usr/lib/ghc-8.10.5/site-local/tagged-0.8.6.1
library-dirs:         /usr/lib/ghc-8.10.5/site-local/tagged-0.8.6.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/i386-linux-ghc-8.10.5/tagged-0.8.6.1
hs-libraries:         HStagged-0.8.6.1-F25vmSN4H5fEaMJYsLgYMV
depends:
    base-4.14.2.0 deepseq-1.4.4.0 template-haskell-2.16.0.0
    transformers-0.5.6.2

haddock-interfaces:   /usr/share/doc/haskell-tagged/html/tagged.haddock
haddock-html:         /usr/share/doc/haskell-tagged/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

